@@ -43,7 +43,7 @@
       integer TA
       E = E1
       do i = 1, nebin
-         pj.fm.p(4) = E
+         pj%fm%p(4) = E
          sum = 0.
          do  j = 1, nel
                                        ! charge is not use so rough
@@ -121,7 +121,7 @@
       call computeXS(pj, xs)
 !         output
       E= E1
-      write(*,'(a,i2,i4,i3)') '# pj=',pj.code, pj.subcode, pj.charge
+      write(*,'(a,i2,i4,i3)') '# pj=',pj%code, pj%subcode, pj%charge
       write(*,'(a, 15(i4,f6.3))') '# tg=',(A(i), portion(i), i=1,nel)
       do i = 1, nebin
          write(*,'(1p, 4g13.4 )')  E, xs(i)
