@@ -1,3 +1,12 @@
+!     Make TUNE4M  1 to activate a workaround for the EPOS 4 momentum problem
+!     !=1  ==>  output from EPOS will be accepted as it is; however, in this
+!       case,  the relation,  E^2= p^2+ m^2 of each particls, is
+!       sometimes broken non negligibly.    (see  eposWorkaround.pdf)
+!     ==1  ==> The  energy of each particle is forced to be
+!          sqrt(p^2 + m^2).  This workaround is used in CRMC.
+
+#define TUNE4M 1
+      
       module modEpos
       implicit none
 #include "Zptcl.h"
@@ -153,6 +162,10 @@
       type(ptcl):: tg
       real(8):: xs
 
+!!!!!!!!!!
+!!      real(8):: p2, mass2
+!!!!!!!      
+
       if( ia > 1 ) then
          call cmkptc(kgnuc, ia, iz, tg)
       else
@@ -182,6 +195,13 @@
       
       n = 0
       do i = 1, nhep
+
+#if  TUNE4M == 1
+!          force E=sqrt( m^2+p^2) as in CRMC
+         phep(4,i)=sqrt( dot_product(phep(1:3,i), phep(1:3,i))
+     *      +   phep(5,i)**2  )
+#endif    
+
          kf = idhep(i)
          call ckf2cos(kf, code, subcode, charge)
 !///////////
@@ -220,6 +240,15 @@
                a(n)%fm%p(1:4) = phep(1:4,i)
                !    use mass in phep
                a(n)%mass = phep(5,i)
+!!!!  /////////////
+!               
+!               p2 =  dot_product(a(n)%fm%p(1:3), a(n)%fm%p(1:3) )
+!               mass2= a(n)%fm%p(4)**2 - p2
+!
+!               write(*,'(3i5,1p,6g15.5)')
+!     *              a(n)%code, a(n)%subcode, a(n)%charge,
+!     *              a(n)%fm%p(:), a(n)%mass, sqrt(mass2)
+!///////////////               
             endif
          endif
       enddo
@@ -893,3 +922,6 @@
 
       RETURN
       END
+
+
+
