@@ -1,3 +1,12 @@
+!     Make TUNE4M  1 to activate a workaround for the EPOS 4 momentum problem
+!     !=1  ==>  output from EPOS will be accepted as it is; however, in this
+!       case,  the relation,  E^2= p^2+ m^2 of each particls, is
+!       sometimes broken non negligibly.    (see  eposWorkaround.pdf)
+!     ==1  ==> The  energy of each particle is forced to be
+!          sqrt(p^2 + m^2).  This workaround is used in CRMC.
+
+
+#define TUNE4M  1
       module modEpos
       implicit none
 #include "Zptcl.h"
@@ -180,6 +189,12 @@
       
       n = 0
       do i = 1, nhep
+#if  TUNE4M == 1
+!          force E=sqrt( m^2+p^2) as in CRMC
+         phep(4,i)=sqrt( dot_product(phep(1:3,i), phep(1:3,i))
+     *      +   phep(5,i)**2  )
+#endif    
+
          kf = idhep(i)
          call ckf2cos(kf, code, subcode, charge)
 !///////////
