@@ -7,13 +7,13 @@
       implicit none
 #include "Zptcl.h"
 #include "Zcode.h"
-      record /ptcl/ pj  ! input projectile heavy ion
+      type(ptcl):: pj  ! input projectile heavy ion
          ! momentum is  not used. only code, subcode,charge
          ! mass and Et are used.
 
       integer,intent(in):: ita, itz  ! target A, Z
       integer,intent(in):: Nsp   ! # of  spectator nucleons
-      record /ptcl/a(*)  ! output. Nsp nucleons are
+      type(ptcl)::a(*)  ! output. Nsp nucleons are
                         ! classified into various fragments
                         ! and stored here.  P is given
                         ! assuming  pj is moving z-direction.
@@ -38,16 +38,16 @@
 
       real(8),allocatable::cumSig(:)
       real(8):: u, v
-      record /ptcl/ p0
+      type(ptcl):: p0
       real(8),parameter:: adjustP = 0.1
       real(8),parameter:: adjustHe = 0.1
 
-      if( pj.code /= kgnuc ) then
+      if( pj%code /= kgnuc ) then
          call cerrorMsg('pj is non heavy in csmapNucFrag',0)
       endif
-      pA = pj.subcode
-      pZ = pj.charge
-      KEpn =( pj.fm.p(4) - pj.mass )/pA
+      pA = pj%subcode
+      pZ = pj%charge
+      KEpn =( pj%fm%p(4) - pj%mass )/pA
 !!!!!!!!!!!!
 !      write(0,*) ' pA=',pA, ' pZ=',pZ, ' Nsp=',Nsp
 !      write(0,*) ' KEpn=',KEpn
@@ -113,8 +113,8 @@
          write(0,*)
      *    'Msg from csampNucFrag: nfrag=0 kount2=',KOUNT2,
      * ' sumAll=',sumAll
-         write(0,*) ' pj: A, Z',pj.subcode, pj.charge
-         write(0,*) ' pj: KE/n=', (pj.fm.p(4)-pj.mass)/pj.subcode
+         write(0,*) ' pj: A, Z',pj%subcode, pj%charge
+         write(0,*) ' pj: KE/n=', (pj%fm%p(4)-pj%mass)/pj%subcode
          write(0,*) ' # of spectator n=', Nsp
          write(0,*) ' target A,Z=',ita, itz
          if( KOUNT2 > 0 ) then
@@ -198,7 +198,7 @@
          enddo
       enddo
 !           assume charge in spectator
-      Zav = dble(pj.charge)/pj.subcode *Nsp + 0.5
+      Zav = dble(pj%charge)/pj%subcode *Nsp + 0.5
       if( Zspec > Zav ) then
          dZ = Zspec - Zav
          if( Znuc > dZ ) then
@@ -206,9 +206,9 @@
             nnc = 0
 
             do i = 1, np
-               if( a(i).code == knuc ) then
+               if( a(i)%code == knuc ) then
                   nnc = nnc + 1
-                  a(i).charge = 0
+                  a(i)%charge = 0
                   if(nnc == dZ ) exit
                endif
             enddo
@@ -216,26 +216,26 @@
       endif
 !!!!!!!!!!!!
 !      do i = 1, np
-!         write(0,*)i, a(i).code, a(i).subcode, a(i).charge
+!         write(0,*)i, a(i)%code, a(i)%subcode, a(i)%charge
 !      enddo
 !!!!!!
 
 !           give E,P to fragment  and p,n at spectator frame
       do i = 1, np
-         chg = a(i).charge
-         if( a(i).code == knuc ) then
-            call csampFermiMom(Nsp, Zav,  chg, a(i).fm.p)
+         chg = a(i)%charge
+         if( a(i)%code == knuc ) then
+            call csampFermiMom(Nsp, Zav,  chg, a(i)%fm%p)
          else
-            Ai = a(i).subcode
-            call csampHFMom(Nsp, Zav, Ai, chg, a(i).fm.p, dummyp)
+            Ai = a(i)%subcode
+            call csampHFMom(Nsp, Zav, Ai, chg, a(i)%fm%p, dummyp)
          endif
-         a(i).fm.p(4) = 
-     *  sqrt( dot_product( a(i).fm.p(1:3), a(i).fm.p(1:3)) +
-     *       a(i).mass**2)
+         a(i)%fm%p(4) = 
+     *  sqrt( dot_product( a(i)%fm%p(1:3), a(i)%fm%p(1:3)) +
+     *       a(i)%mass**2)
       enddo
       p0 = pj
-      p0.fm.p(3) = sqrt(pj.fm.p(4)**2 - pj.mass**2)
-      p0.fm.p(1:2) = 0.
+      p0%fm%p(3) = sqrt(pj%fm%p(4)**2 - pj%mass**2)
+      p0%fm%p(1:2) = 0.
       do i = 1, np
          call cibst1(i, p0, a(i), a(i))
       enddo
