@@ -100,7 +100,10 @@
 !$$$$$$$$$$
 !             get gzai to transform massive case
            call cnbdc3(n, ecm, p, mu, 0,  gzai, icon)
-!          **********************
+!     **********************
+           if(icon /= 0 ) then  !!!!!!!
+              write(0,*) ' icon =',icon, ' from cnbdc3'
+           endif             !!!!!!!!
            if(icon .ne. 0) return
 !          **********************
 !             tranform to massive case
@@ -141,7 +144,7 @@
            endif
            if(ok) goto 100
 	   nc = nc +1
-	   if(nc .gt. 20) then
+	   if(nc .gt. 100) then
 	      icon = 2
 	      goto 100
            endif
