@@ -1,4 +1,4 @@
-c              #include Zcode.h is needed
+!              #include Zcode.h is needed
         integer nmax, maxDecay
         parameter  ( nmax = 50000,  maxDecay = 8 )
         integer Jdecay(klast)
