@@ -1,13 +1,13 @@
 #include "ZcosmosBD.h"
       implicit none
 #include "Zptcl.h"
-c#include "Zcode.h"
-c#include "Zmass.h"
+!#include "Zcode.h"
+!#include "Zmass.h"
       real*8  xs, p, xspp, xspA, A
       integer iat
-      record /ptcl/ pj
+      type(ptcl):: pj
 
-c     
+!     
       real(8):: Ek
       integer code, subcode, charge, i
 
@@ -20,7 +20,7 @@ c
       call ciniQGS
       call cmkptc(code, subcode, charge, pj)
       write(*,'(a)')
-c     *    '# Ek(GeV) Xs(targetA) Xs(pp) Xs(targetAbyCos) mom'
+!     *    '# Ek(GeV) Xs(targetA) Xs(pp) Xs(targetAbyCos) mom'
      *    '# Ek(GeV) Xs(targetA) mom'
 
       do while (Ek .lt. 1.e11)
@@ -29,11 +29,11 @@ c     *    '# Ek(GeV) Xs(targetA) Xs(pp) Xs(targetAbyCos) mom'
          pj.fm.p(2) = 0.
          pj.fm.p(3) = p
          pj.fm.p(4) = Ek + pj.mass
-c         Ek =  pj.fm.p(4) - pj.mass
+!         Ek =  pj.fm.p(4) - pj.mass
          call cxsecQGS( pj, iat,   xs )
-c         call cxsecQGS( pj, 1,  xspp)
-c         call cxp2xAXsec(A, xspp,  xspA)
-c         write(*,'(1p,5g12.4)')  Ek, xs, xspp, xspA, p
+!         call cxsecQGS( pj, 1,  xspp)
+!         call cxp2xAXsec(A, xspp,  xspA)
+!         write(*,'(1p,5g12.4)')  Ek, xs, xspp, xspA, p
          write(*,'(1p,3g12.4)')  Ek, xs, p
          Ek = Ek*10.0**0.1
       enddo
