@@ -121,13 +121,13 @@
                   xs = shp
                endif
             endif
-         elseif(pj%code == kpion .or. pj%code == keta) then
+         elseif(pj%code == kpion ) then
             if(pj%charge .eq. 1) then
                call cpippInelaXs(p, shp)
             elseif(pj%charge .eq. -1) then
                call cpimpInelaXs(p, shp) 
             else 
-                  ! pi0 or eta
+                  ! pi0 
                call cpimpInelaXs(p, shp)
             endif
             if(A .ne. 1.0) then
@@ -195,32 +195,37 @@
             xs= smallxs
          elseif(pj%code .eq. kneue) then
             xs= smallxs
+         elseif(pj%code == kneutau) then
+            xs= smallxs
          elseif(pj%code == knnb .or. pj%code == kddb ) then
             xs = smallxs
          elseif(pj%code == kmuon) then
             write(0,*) 'cinelx: code=',pj%code, ' should not come'
             stop
          else
-!          use pion
-            call cpippInelaXs(p, shp)
-            call cxp2xAXsec(A, shp, xs)               
+!     eta, ds, Xic,  etc
+           xs = smallxs 
+!!          use pion
+   !         call cpippInelaXs(p, shp)
+   !         call cxp2xAXsec(A, shp, xs)               
          endif
       endif
 !!!       normalize to pdg at 200 GeV. norm const is
-!!!       applied to other collisions 
-      if(A > 1. .and. A /=  Aprev ) then
-         call cppInelaXs(200.d0, xs200)
-         call cxp2xAXsec(A, xs200, xs200A)
+!!!   applied to other collisions
+      if( xs /= smallxs ) then
+         if(A > 1. .and. A /=  Aprev ) then
+            call cppInelaXs(200.d0, xs200)
+            call cxp2xAXsec(A, xs200, xs200A)
 !!         write(0,*) ' xs200A=',xs200A, ' pgd=',  cPDGsigmaInepA(A)
-         norm =  cPDGsigmaInepA(A) /xs200A
+            norm =  cPDGsigmaInepA(A) /xs200A
 !!         write(0,*) ' norm=', norm
-         Aprev = A
-      elseif( A == 1.)  then
-         norm = 1.
-         Aprev = A
+            Aprev = A
+         elseif( A == 1.)  then
+            norm = 1.
+            Aprev = A
+         endif
+         xs = xs*norm
       endif
-      xs = xs*norm
-
       end
       function cinelCosByPdg(A)  result(ratio)
 !             sigmaInela(pA)cosmos/sigmaInela(pA)PDG
