@@ -7,6 +7,10 @@ ShowIntModel () {
     epos=`(cd  $COSMOSTOP/Import; ls -l EPOS) | awk '{print  $NF}' | awk -F / '{print $NF}'`
 #    (cd  $COSMOSTOP/Import; ls -l EPOS) | awk '{printf("%s %s ", $(NF-2), $(NF-1) )}'
     echo If IntModel in \$PARAM contains \"epos\", it  means $epos
+
+
+    sibyll=`(cd  $COSMOSTOP/Import; ls -l Sibyll) | awk '{print  $NF}' | awk -F / '{print $NF}'`
+    echo If IntModel in \$PARAM contains \"sibyll\", it  means $sibyll
   }
 
 
@@ -26,9 +30,10 @@ cat <<EOF
 If want to use a different model, select a number
      1) qgsjetII-04 or qgsjetII-03
      2) epos-lhc-v3700 or epos199 or epos-lhc-v3400
+     3) sibyll2.3c or sibyll2.1
  other) exit
 
-  If you need to use  both 1 and 2, use intModel.sh 2 times.
+  If you need to change two or more models, use intModel.sh 2 times or more.
 EOF
 read ans
 if [ -z $ans ]; then
@@ -39,6 +44,8 @@ if [ $ans == 1 ]; then
     $COSMOSTOP/Scrpt/fixQGSII.sh
 elif [ $ans == 2 ]; then
     $COSMOSTOP/Scrpt/fixEPOS.sh
+elif [ $ans == 3 ]; then
+    $COSMOSTOP/Scrpt/fixSibyll.sh
 else
     exit
 fi
