@@ -163,7 +163,6 @@
       integer devn, icon, leng, kgetenv
       save devn
       data devn /12/
-
       NULL = char(0)
 
       if(filepath .eq. ' ') then
@@ -184,7 +183,6 @@
          call cerrorMsg(
      *        'above file cannot be opened for geomagnetic data', 0)
       endif
-
       call cgmgIgrf(devn, path, yearin)
       end
 !     *************************
@@ -241,8 +239,15 @@
 !       first find the appropriate year
       year = yearin
       msg = ' '
-      read(devn, '(a)' ) msg
-
+!     format changed from igrf12:  skip if first col. is # or c/s
+      do 
+         read(devn, '(a)' ) msg
+         if( msg(1:1) /= "#" .and. msg(1:3) /= "c/s") exit
+      enddo
+!     chagne for igrf12 ended.  igrf10 can be read also.
+      
+      
+!         now msg should start with "g/h"
       call kcountFields(msg, nf)
       if(nf < 5) then
          write(0,*) ' input igrf data is invalid'
@@ -251,7 +256,6 @@
          stop 9999
       endif
       call kcgetaField(msg, 4, n1, n2)      
-
       if(n1 <= 0) then
          write(0,*) ' strange in cgmgIgrf'
          stop 9999
@@ -261,7 +265,6 @@
       
       call kcgetaField(msg, nf-1, n1, n2)
       read( msg(n1:n2), *)  yearmax
-
       targetf2 = 5
       if(year < year1 ) then
          targetf1 = 4
