@@ -1,4 +1,25 @@
-      subroutine cGetXsec(model, pj, media, xs, mfp)
+      subroutine cGetXsec2(model, pj, media, xs, mfp)
+      ! normally this is not to be used. use cGetXsec
+      use modXsecMedia, xmedia=>media
+      implicit none
+#include "Zcode.h"
+#include "Zptcl.h"
+#include "Zevhnp.h"
+      character(*),intent(in):: model
+      type(ptcl)::pj           ! input.   projectile 
+      type(xsmedia),intent(inout):: media ! media 
+      real(8),intent(out):: xs  ! collision xsection in mb
+                    !    if xs==smallxs, no collision
+                    !       xs==largexs, instant collision
+      real(8),intent(out):: mfp ! mean free path in kg/m2
+
+      call cGetXsec(model, pj, media, xs, mfp)
+      if(xs /= largexs .and. xs /= smallxs) then
+         xs = xs * media%sumNo
+      endif
+      end subroutine cGetXsec2
+
+      subroutine cGetXsec(modelin, pj, media, xs, mfp)
 ! @JAXA, xs=0 leads to 0-divide error and after 10 repeats
 ! stop is made.  At other systems, 0 divide
 ! in this case has no bad effect. 
@@ -17,47 +38,60 @@
 #include "Zcode.h"
 #include "Zptcl.h"
 #include "Zevhnp.h"
-      character(*),intent(in):: model
-      record /ptcl/pj           ! input.   projectile 
+      character(*),intent(in):: modelin
+      type(ptcl)::pj           ! input.   projectile 
       type(xsmedia),intent(inout):: media ! media 
       real(8),intent(out):: xs  ! collision xsection in mb
                     !    if xs==smallxs, no collision
                     !       xs==largexs, instant collision
       real(8),intent(out):: mfp ! mean free path in kg/m2
 
-      if( pj.code == knuc ) then
-         if( pj.subcode == antip .and. pj.fm.p(4) - pj.mass <= 0.) then
+      character(8):: model
+      
+      if( pj%code == knuc ) then
+         if( pj%subcode == antip .and. pj%fm%p(4) - pj%mass <= 0.) then
             xs = largexs
             media%xs = xs
             mfp = 0. 
             return  ! *******************
          endif
-      elseif( pj.code == kneue .or. pj.code == kneumu ) then
+      elseif( pj%code == kneue .or. pj%code == kneumu ) then
          xs = smallxs
          media%xs = xs
          mfp  = largexs
          return                 ! *******************
       endif
-      select case(model)
-        case( "phits" ) 
-           call cxsPhits(pj, media)
-        case( "dpmjet3" )
-           call cxsDpmjet3(pj, media)
-        case( "jam" ) 
-           call cxsJam(pj, media)
-        case( "qgsjet2" )
-           call cxsQgsjet2(pj, media)
-        case( "epos" )
-           call cxsEPOS(pj, media)
-        case( "sibyll" )
-           call cxsSibyll(pj, media)
-        case( "gheisha" ) 
-           call cxsGheisha(pj, media)
-        case("incdpm3")   
-           call cxsIncdpm3(pj, media)
-        case default
-         call cxsOther( pj, media)
-      end select
+
+      model = modelin      
+      if( model == "special" ) then
+!     model might be given in next call on return by the user;
+!     (pj and target are not suited for  giving xs so that
+!     some another relevant model  might have been given there for XS calc.
+         call cxsSpecial(pj, media, model)
+      endif
+       
+      if( model /= "special" ) then
+        select case(model)
+          case( "phits" ) 
+            call cxsPhits(pj, media)
+         case( "dpmjet3" )
+            call cxsDpmjet3(pj, media)
+         case( "jam" ) 
+            call cxsJam(pj, media)
+         case( "qgsjet2" )
+            call cxsQgsjet2(pj, media)
+         case( "epos" )
+            call cxsEPOS(pj, media)
+         case( "sibyll" )
+            call cxsSibyll(pj, media)
+         case( "gheisha" ) 
+            call cxsGheisha(pj, media)
+         case("incdpm3")   
+            call cxsIncdpm3(pj, media)
+         case default
+            call cxsOther( pj, media)
+         end select
+      endif
       if(media%xs < smallxs) then
          media%xs = smallxs
       endif
@@ -69,6 +103,7 @@
          mfp = 0.
       endif
       xs = media%xs
+
       end subroutine cGetXsec
 
 
@@ -79,26 +114,29 @@
 #include "Zcode.h"
 #include "Ztrackp.h"
 #include "Zevhnp.h"
-      record /ptcl/ pj  ! input ptcl
+      type(ptcl)::pj  ! input ptcl
       type(xsmedia),intent(inout):: media    ! input/output
 
 
-      integer i
-      real(8):: sumns,  xs
-      sumns=0. 
+      integer i, iA
+      real(8):: sumns,  xs, iAR
+      sumns=0.
+
       do i = 1, media%noOfElem
-         if(pj.code >= kpion .and. pj.code <= knuc ) then
+         iA = media%elem(i)%A + 0.5d0
+         iAR =  iA
+         if(pj%code >= kpion .and. pj%code <= knuc ) then
             if( JamXs == 1 ) then
-               call ctotx(pj, media%elem(i)%A,  xs)
+               call ctotx(pj, iAR,  xs)
             elseif( JamXs == 0 ) then
-               call cinelx(pj, media%elem(i)%A, media%elem(i)%Z, xs)
+               call cinelx(pj, iAR, media%elem(i)%Z, xs)
             else
                write(0,*)
      *          ' JamXs=',JamXs, ' not usable in cxsJam'
                stop
             endif
          else
-            call cinelx(pj, media%elem(i)%A,  media%elem(i)%Z, xs)
+            call cinelx(pj, iAR,  media%elem(i)%Z, xs)
          endif
          if( xs <  smallxs ) then
             xs = smallxs
@@ -120,7 +158,7 @@
 #include "Zptcl.h"
 #include "Zcode.h"
 #include "Zevhnp.h"
-      record /ptcl/ pj  ! input ptcl
+      type(ptcl)::pj  ! input ptcl
       type(xsmedia),intent(inout):: media    ! input/output
 
 
@@ -129,16 +167,16 @@
       integer::ka, subc, ia, iz
 
       sumns=0. 
-      ka = pj.code
-      subc = pj.subcode
+      ka = pj%code
+      subc = pj%subcode
       do i =1, media%noOfElem
          ia = media%elem(i)%A + 0.5
          iz = media%elem(i)%Z
          if( ( ka == knuc .and. subc /= antip )
      *        .or. ka == kgnuc) then
             call cphitsXs(pj, ia, iz, elaxs,xs, icon)
-cc             no need to add. xs is already total 2010.Nov.16
-ccc            xs = xs + elaxs  ! phits elaxs for heavy is 0
+!c             no need to add. xs is already total 2010.Nov.16
+!cc            xs = xs + elaxs  ! phits elaxs for heavy is 0
          else
 !            if( ka >= kpion .and. ka <= knuc ) then
 !               if( (pj.fm.p(4)-pj.mass)  < 10.d0 )  then ! include elastic
@@ -168,30 +206,35 @@ ccc            xs = xs + elaxs  ! phits elaxs for heavy is 0
 #include "Zptcl.h"
 #include "Zcode.h"
 #include "Zevhnp.h"
-      record /ptcl/ pj  ! input ptcl
+      type(ptcl)::pj  ! input ptcl
       type(xsmedia),intent(inout):: media    ! input/output
 
-      integer i
-      real(8):: sumns,  xs
+      integer i,  iA
+      real(8):: sumns,  xs, iAR
 
       sumns=0. 
       do i =1, media%noOfElem
-         if( pj.code >= kpion .and. pj.code <= knuc ) then
-            if( pj.fm.p(4) .lt.  4.1d0 ) then  ! Et is better than Ek
-               call ctotx(pj, media%elem(i)%A,  xs)
-c//////////////////
-c               if( pj.code == 6 .and. pj.charge == -1  .and.
-c     *              (pj.fm.p(4)- pj.mass) < 1d-3 ) then
-c                  write(0,*) '********* ', pj.fm.p(4)-pj.mass,
-c     *             xs
-c                  write(0,*) ' largexs=',largexs
-c               endif
-c///////////////////
+         iA = media%elem(i)%A + 0.5d0
+         iAR = iA
+         if( pj%code >= kpion .and. pj%code <= knuc ) then
+            if( pj%fm%p(4) .lt.  4.1d0 ) then ! Et is better than Ek
+!              call ctotx(pj, media%elem(i)%A,  xs)  !2017/sep/20 
+               call ctotx(pj, iAR,  xs)
+!//////////////////
+!               if( pj.code == 6 .and. pj.charge == -1  .and.
+!     *              (pj.fm.p(4)- pj.mass) < 1d-3 ) then
+!                  write(0,*) '********* ', pj.fm.p(4)-pj.mass,
+!     *             xs
+!                  write(0,*) ' largexs=',largexs
+!               endif
+!///////////////////
             else
-               call cinelx(pj, media%elem(i)%A,  media%elem(i)%Z, xs)
+!     call cinelx(pj, media%elem(i)%A,  media%elem(i)%Z, xs)
+               call cinelx(pj, iAR,  media%elem(i)%Z, xs)
             endif
          else
-            call cinelx(pj, media%elem(i)%A, media%elem(i)%Z, xs)
+            call cinelx(pj, iAR, media%elem(i)%Z, xs)
+!            call cinelx(pj, media%elem(i)%A, media%elem(i)%Z, xs)
          endif
          if( xs <= smallxs .or. xs == largexs ) then
             sumns = xs
@@ -211,7 +254,7 @@ c///////////////////
 #include "Zptcl.h"
 #include "Zcode.h"
 #include "Zevhnp.h"
-      record /ptcl/ pj  ! input ptcl
+      type(ptcl)::pj  ! input ptcl
       type(xsmedia),intent(inout):: media    ! input/output
 
 
@@ -223,13 +266,20 @@ c///////////////////
       do i =1, media%noOfElem
          tga = media%elem(i)%A
          tgz = media%elem(i)%Z
-         ia =tga 
-         call rndc(u)
-         if(u .lt.  tga - ia ) then
-            ia = min(ia + 1, 209)
-         endif
-         if( (pj.code >= kpion .and. pj.code <= knuc) .or. 
-     *        pj.code == kgnuc ) then
+!         ia =tga 
+!         call rndc(u)
+!         if(u .lt.  tga - ia ) then
+!            ia = min(ia + 1, 209)
+!         endif
+!     above  method is not so good. should  statistically be ok
+!     For H2,  A  is 1.008 so some times ia becomes 2. If one makes
+!     a table, 2 is always used. and dangerous.  To be accurate
+!     media must be mixed A=1 andn A=2...
+!     Now we treat such case roughly.  by round off (四捨五入)
+         ia = tga + 0.5d0
+         ia = min(ia, 209)
+         if( (pj%code >= kpion .and. pj%code <= knuc) .or. 
+     *        pj%code == kgnuc ) then
             call cxsecQGS(pj, ia, xs)               
          else
             call cinelx(pj, tga, tgz, xs)
@@ -252,32 +302,34 @@ c///////////////////
 #include "Zptcl.h"
 #include "Zcode.h"
 #include "Zevhnp.h"
-      record /ptcl/ pj  ! input ptcl
+      type(ptcl)::pj  ! input ptcl
       type(xsmedia),intent(inout):: media    ! input/output
 
       integer i, ia, iz
       real(8):: sumns,  xs, tga, u, tgz
 
-      record /ptcl/ tg
+      type(ptcl)::tg
 
       sumns=0. 
       do i =1, media%noOfElem
          tga = media%elem(i)%A
          tgz = media%elem(i)%Z
-         ia =tga 
-         iz =tgz 
-         call rndc(u)
-         if(u .lt.  tga - ia ) then
-            ia = min(ia + 1, 209)
-         endif
+         ia =tga + 0.5d0
+         iz =tgz
+!          see qgs part         
+!         ia = tga
+!         call rndc(u)
+!         if(u .lt.  tga - ia ) then
+!            ia = min(ia + 1, 209)
+!         endif
 
          if(ia > 1 ) then
             call cmkptc(kgnuc, ia, iz, tg)
          else
             call cmkptc(knuc, ia, iz, tg)
          endif
-         tg.fm.p(1:3) = 0.
-         tg.fm.p(4) = tg.mass
+         tg%fm%p(1:3) = 0.
+         tg%fm%p(4) = tg%mass
          call ceposIniOneEvent(pj, tg, xs)
          if( xs <= smallxs .or. xs == largexs ) then
             sumns = xs
@@ -296,43 +348,57 @@ c///////////////////
 #include "Zptcl.h"
 #include "Zcode.h"
 #include "Zevhnp.h"
-      record /ptcl/ pj  ! input ptcl
+      type(ptcl)::pj  ! input ptcl
       type(xsmedia),intent(inout):: media    ! input/output
 
       integer i, ia, iz
       real(8):: sumns,  xs, tga, u, tgz
 
-      record /ptcl/ tg
+      type(ptcl)::tg
 
       sumns=0. 
       do i =1, media%noOfElem
          tga = media%elem(i)%A
          tgz = media%elem(i)%Z
-         ia =tga 
-         iz =tgz 
-         call rndc(u)
-         if(u .lt.  tga - ia ) then
-            ia = min(ia + 1, 209)
-         endif
-
+         iz =tgz
+         ia = tga + 0.5d0
+!     see QGS part
+!                 ia =tga 
+!         call rndc(u)
+!         if(u .lt.  tga - ia ) then
+!            ia = min(ia + 1, 209)
+!         endif
+         ia = min(ia, 209)
          if(ia > 1 ) then
             call cmkptc(kgnuc, ia, iz, tg)
          else
             call cmkptc(knuc, ia, iz, tg)
          endif
-         tg.fm.p(1:3) = 0.
-         tg.fm.p(4) = tg.mass
-         if( media%name == "Air" ) then
-            tg.subcode = 0  !sibyll can do for almost Air target only. 
+         tg%fm%p(1:3) = 0.
+         tg%fm%p(4) = tg%mass
+         if( media%name == "Air" )then
+            if( i == 1) then 
+               tg%subcode = 0   !sibyll can do for almost Air target only.
+               call csibyllXs(pj, tg, xs)
+            else
+               xs =0.
+            endif
+         else
+            call csibyllXs(pj, tg, xs)
+            if( xs <= smallxs .or. xs == largexs ) then
+               sumns = xs
+               exit
+            endif
          endif
-         call csibyllXs(pj, tg, xs)
-         if( xs <= smallxs .or. xs == largexs ) then
-            sumns = xs
-            exit
+         if( media%name ==  "Air") then
+!           only 1 virtual element 'air' so weight should be 1
+!     In the event generator, should not choose N target
+!     but use "air" target.  i>1 xs=0
+            media%elem(i)%nsigma = xs
          else
             media%elem(i)%nsigma = xs*media%elem(i)%No
-            sumns = sumns + media%elem(i)%nsigma
          endif
+         sumns = sumns + media%elem(i)%nsigma
       enddo
       media%xs = sumns
       end subroutine cxsSibyll
@@ -343,7 +409,7 @@ c///////////////////
 #include "Zptcl.h"
 #include "Zcode.h"
 #include "Zevhnp.h"
-      record /ptcl/ pj  ! input ptcl
+      type(ptcl)::pj  ! input ptcl
       type(xsmedia),intent(inout):: media    ! input/output
 
       integer i, ia
@@ -354,7 +420,7 @@ c///////////////////
       do i =1, media%noOfElem
          tga = media%elem(i)%A
          tgz = media%elem(i)%Z
-         if(pj.code  >= kpion .and. pj.code <= knuc ) then
+         if(pj%code  >= kpion .and. pj%code <= knuc ) then
             call cxsecGheisha(pj, tga,  tgz, xs)
          else
             call cinelx(pj, tga, tgz, xs)
@@ -377,16 +443,16 @@ c///////////////////
 #include "Zcode.h"
 #include "Zevhnp.h"
           
-      record /ptcl/ pj      ! input.  a particle (hadronic)
+      type(ptcl)::pj      ! input.  a particle (hadronic)
       type(xsmedia),intent(inout):: media    ! input/output
 
       real(8):: ek, crossint
       integer:: kinc
 
-      ek = pj.fm.p(4)- pj.mass
+      ek = pj%fm%p(4)- pj%mass
       if( ek > 0.2d0 ) then
-c            special for inclusive treatment.  target is always air   
-c         *********************************                           
+!            special for inclusive treatment.  target is always air   
+!         *********************************                           
          call cccode2hcode(pj, kinc)
          media%xs = crossint(kinc, ek)
       else
@@ -401,19 +467,22 @@ c         *********************************
 #include "Zcode.h"
 #include "Zevhnp.h"
           
-      record /ptcl/ pj      ! input.  a particle (hadronic)
+      type(ptcl)::pj      ! input.  a particle (hadronic)
       type(xsmedia),intent(inout):: media    ! input/output
 
  
-      integer i
-      real(8):: sumns, xs
+      integer i, iA
+      real(8):: sumns, xs, iAR
 
       sumns = 0.
-        do i = 1, media%noOfElem
-         call cinelx(pj, media%elem(i)%A, media%elem(i)%Z, xs)
-c//////////////
-c         write(0,*) 'in othert;  xs=',xs, i,  media%noOfElem
-c////////////
+      
+      do i = 1, media%noOfElem
+         iA =  media%elem(i)%A + 0.5d0
+         iAR = iA
+         call cinelx(pj, iAR, media%elem(i)%Z, xs)
+!//////////////
+!         write(0,*) 'in othert;  xs=',xs, i,  media%noOfElem
+!////////////
          if( xs <= smallxs .or. xs == largexs ) then
             sumns = xs
             exit
@@ -430,9 +499,9 @@ c////////////
       implicit none
 #include "Zevhnp.h"
 
-c
-c       Fix the target element, 
-c  
+!
+!       Fix the target element, 
+!  
       type(xsmedia),intent(inout):: media  ! input/output
                         !   xsmedia information.
 
@@ -464,16 +533,16 @@ c
       endif
  10   continue
       colElemNo = j
-c          int value is taken.
-cc      if(model .eq. "dpmjet3" ) then
+!          int value is taken.
+!c      if(model .eq. "dpmjet3" ) then
       ia = media%elem(j)%A  + 0.5
-cc      else
-cc         call rndc(u)
-cc         ia = media%elem(j).A
-cc         if(u .lt. media%elem(j).A -ia ) then
-cc            ia = ia + 1
-cc         endif
-cc      endif
+!c      else
+!c         call rndc(u)
+!c         ia = media%elem(j).A
+!c         if(u .lt. media%elem(j).A -ia ) then
+!c            ia = ia + 1
+!c         endif
+!c      endif
          
 !      media%colZ = media%elem(j)%Z
 !      media%colA = ia
@@ -565,10 +634,10 @@ cc      endif
 #include "Zptcl.h"
 #include "Zcode.h"
 #include "Zevhnp.h"
-c   
+!   
       character*16 model    ! input. Active interaction model.
             ! for x-section calclation .  at present not used
-      record /ptcl/ pj      ! input.  a photon
+      type(ptcl)::pj      ! input.  a photon
       type(xsmedia),intent(inout):: media  ! input
       real(8),intent(out):: xs   !  obtained cross-section for the
                             !  media% in mb
@@ -581,7 +650,7 @@ c
 
       sumns = 0.
       do i = 1, media%noOfElem
-         call cgpXsec(media%elem(i)%A, pj.fm.p(4), xs)
+         call cgpXsec(media%elem(i)%A, pj%fm%p(4), xs)
          if( xs < smallxs ) then
             xs = smallxs
          endif
