@@ -37,7 +37,7 @@
 !          If ObsPlane = spherical, do the same tentatively.
 !            (in this case Za1ry == 'is' or 'cos' guaranteed).
 
-         call csPrimAng(angle)
+         call csPrimAng(angle)   ! angle is in det sys
          call cmkInc(incident, angle)
 #if LABELING > 0
          incident%info = 0
