@@ -1,12 +1,12 @@
-c     ******************************************************************
-c     *                                                                *
-c     * csampNEPIntL: samples integraction length for a given
-c     *              non e, gamma  particle in a given material air
-c     *                                                                *
-c     ******************************************************************
-cc            From Epicsv7.0. this is not used from Epcis
-c       I.e. this is for Air
-c     *****************************************************************
+!     ******************************************************************
+!     *                                                                *
+!     * csampNEPIntL: samples integraction length for a given
+!     *              non e, gamma  particle in a given material air
+!     *                                                                *
+!     ******************************************************************
+!c            From Epicsv7.0. this is not used from Epcis
+!       I.e. this is for Air
+!     *****************************************************************
       subroutine  csampNEPIntL
       use modXsecMedia
       implicit none
@@ -16,32 +16,32 @@ c     *****************************************************************
 #include  "Ztrackv.h"
 #include  "Zevhnp.h"
 
-c     **************************************************
-c
+!     **************************************************
+!
       real*8 mfp, xs, length
 
-c            
-c        m.f.p (kg/m**2) = abn /xsec(mb)
+!            
+!        m.f.p (kg/m**2) = abn /xsec(mb)
 #if defined (LOOPCHK)
       integer ksave/0/, esave/-1./, ncount/0/
       integer ka
       save
-      ka = TrackBefMove.p.code
+      ka = TrackBefMove%p%code
 
       if(ksave .eq. ka .and. esave .eq.  
-     *   TrackBefMove.p.fm.p(4)) then
+     *   TrackBefMove%p%fm%p(4)) then
          ncount = ncount +1
          if(ncount .gt. 10) then
             write(0,*)'  ncount=',ncount, 
      *        ' ka=',ka, ' e=',esave, ' mass=',
-     *      TrackBefMove.p.mass
+     *      TrackBefMove%p%mass
          endif
       else
          ksave =ka
-         esave = TrackBefMove.p.fm.p(4)
+         esave = TrackBefMove%p%fm%p(4)
          ncount =0
       endif
-c///////////////////
+!///////////////////
 #endif
 
       call cdecayLeng(TrackBefMove, length)
@@ -49,21 +49,21 @@ c///////////////////
       if(length .ne. Infty) then
          call csetIntInf(length, .true., 'decay')
       endif
-c      nnb ddb rho phi omega ---> length=0 (instant decay)
-c              or stopping mu pi etc -> length=0 
+!      nnb ddb rho phi omega ---> length=0 (instant decay)
+!              or stopping mu pi etc -> length=0 
       if(length .gt. 0.) then 
-         if(TrackBefMove.p.charge .ne. 0) then
-c                  heavy (non e+/e-) knockon
-c             if Freec and mu or had makes first hadronic
-c             interaction, this call will be non-effective
+         if(TrackBefMove%p%charge .ne. 0) then
+!                  heavy (non e+/e-) knockon
+!             if Freec and mu or had makes first hadronic
+!             interaction, this call will be non-effective
             call cknockonH
          endif
-c                  non stopping-decay paticle
-         if( TrackBefMove.p.code .eq. kmuon) then
-c                   muon; pair, brems, n.i   
+!                  non stopping-decay paticle
+         if( TrackBefMove%p%code .eq. kmuon) then
+!                   muon; pair, brems, n.i   
             call csampMuint(xs, mfp)
          else   
-c                hadronic  collisions
+!                hadronic  collisions
             call csampHadint(xs, mfp)
 
 !           fixing target will be done after collision
@@ -84,15 +84,15 @@ c                hadronic  collisions
       use modXsecMedia
       implicit none
 #include  "Zglobalc.h"
-c #include  "Zcode.h"
+! #include  "Zcode.h"
 #include  "ZbpCnst.h"
 #include  "Ztrackp.h"
 #include  "Ztrack.h"
 #include  "Ztrackv.h"
-c #include  "Zheavyp.h"
+! #include  "Zheavyp.h"
 #include  "Zelemagp.h"
 #include  "Zevhnp.h"
-c #include  "Zevhnv.h"
+! #include  "Zevhnv.h"
 #include  "Zcmuint.h"
       real*8   xs, mfp, u, csigma, s0
 
@@ -102,41 +102,41 @@ c #include  "Zevhnv.h"
 
       xs = smallxs
       if(MuPr .ge. 2 .and.
-     *     TrackBefMove.p.fm.p(4) .gt. muPrEmin) then
-         call cmuPrsmpP(TrackBefMove.p.fm.p(4), prob, path)
-c          prob is /r.l  path is in r.l     
-c          prob   /r.l /X0    --> prob/ (kg/m2) *10 -> prob/(g/cm2)
-c          = mb*4.138e-5
-c            mb2pg = 1.e-27 * Avogn/A = 4.138e-5
-c          xs =prob*10/X0/mb2pg = prob*10/X0*A/Avogn*1.e27
-c             = prob/X0*A/Avogn*1.e28
-c             = prob/X0*A*A2deninv    
-c       (   A2deninv = 1.d28/Avogn   )
-c         xs =max( prob/X0* A2deninv*TargetMassN, smallxs)
-c           n mfp xs =1    
+     *     TrackBefMove%p%fm%p(4) .gt. muPrEmin) then
+         call cmuPrsmpP(TrackBefMove%p%fm%p(4), prob, path)
+!          prob is /r.l  path is in r.l     
+!          prob   /r.l /X0    --> prob/ (kg/m2) *10 -> prob/(g/cm2)
+!          = mb*4.138e-5
+!            mb2pg = 1.e-27 * Avogn/A = 4.138e-5
+!          xs =prob*10/X0/mb2pg = prob*10/X0*A/Avogn*1.e27
+!             = prob/X0*A/Avogn*1.e28
+!             = prob/X0*A*A2deninv    
+!       (   A2deninv = 1.d28/Avogn   )
+!         xs =max( prob/X0* A2deninv*TargetMassN, smallxs)
+!           n mfp xs =1    
          xs =max( prob/mbtoPX0, smallxs)
          mfp = 1./(media(1)%mbtoPkgrm* xs)
          collkgram = path * X0  ! kg/m^2
          call csetIntInf(collkgram, .false., 'mupair')
       endif
       if(MuBr .ge. 2 .and. 
-     *     TrackBefMove.p.fm.p(4) .gt. muBrEmin) then
+     *     TrackBefMove%p%fm%p(4) .gt. muBrEmin) then
                
-         call cmuBrsmpP(TrackBefMove.p.fm.p(4), prob, path)
+         call cmuBrsmpP(TrackBefMove%p%fm%p(4), prob, path)
          xs =max( prob/mbtoPX0, smallxs)
          mfp = 1./(media(1)%mbtoPkgrm* xs)
          collkgram = path * X0 ! kg/m^2
          call csetIntInf(collkgram, .false., 'mubrem')
       endif
       if(MuNI .ge. 2 .and. 
-     *     TrackBefMove.p.fm.p(4) .gt. muNEmin) then
-         call cmuNsmpP(TrackBefMove.p.fm.p(4), prob, path)
+     *     TrackBefMove%p%fm%p(4) .gt. muNEmin) then
+         call cmuNsmpP(TrackBefMove%p%fm%p(4), prob, path)
          xs =max( prob/mbtoPX0, smallxs)
          media(1)%xs = xs  ! for MuNI=3
          mfp = 1./(media(1)%mbtoPkgrm* xs)
          collkgram = path * X0 ! kg/m^2
          if( xs .ne. smallxs .and.
-     *        .not.Freec .and. Zfirst.pos.depth .eq. 0. ) then
+     *        .not. Freec .and. Zfirst%pos%depth .eq. 0. ) then
             collkgram = 0.
          endif
          call csetIntInf(collkgram, .false., 'munuci')
@@ -163,21 +163,21 @@ c           n mfp xs =1
       real(8),intent(out):: mfp !  kg/m2
 
       real*8  prob, path, collkgram, uta, u
-      call cGetXsec(ActiveMdl2,  TrackBefMove.p, media(1),
-     *   xs, mfp)
-c                    for hadronic interaction 
-c                 we can fix the fist col. point at the input
-c                 point when Freec=f
+      call cGetXsec(ActiveMdl2,  TrackBefMove%p, media(1),
+     *     xs, mfp)
+!     for hadronic interaction 
+!                 we can fix the fist col. point at the input
+!                 point when Freec=f
       if(xs .eq. smallxs) then
          collkgram = Infty
-      elseif(.not. Freec .and. Zfirst.pos.depth .eq. 0. ) then
-c         forced collision at the inut deth.
+      elseif(.not. Freec .and. Zfirst%pos%depth .eq. 0. ) then
+!         forced collision at the inut deth.
          collkgram = 0.
       elseif( xs .eq. largexs) then
-c                  say stopping pbar
+!                  say stopping pbar
          collkgram = 0.
       else
-c                 sample interaction length
+!                 sample interaction length
          call rndc(u)
          collkgram=-mfp*log(u)
       endif
@@ -195,8 +195,8 @@ c                 sample interaction length
 #include  "Zelemagp.h"
 #include  "Zevhnv.h"
       real*8 prob, path
-c              knock on by non e+/e- charged ptcl
-      call cKnockp(TrackBefMove.p, prob, path) ! path in r.l
+!              knock on by non e+/e- charged ptcl
+      call cKnockp(TrackBefMove%p, prob, path) ! path in r%l
       if(prob .gt. 0.d0) then
          call csetIntInf(path *X0, .false., 'knock')
       else
