@@ -40,7 +40,7 @@
                   if(TrackBefMove%p%fm%p(4) .le. EasWait) then
                      if(TrackBefMove%p%fm%p(4) .gt. smallAS) then ! 95/08/17
                         call cscalerProd(TrackBefMove%vec%w,
-     *                            DcAtObsXyz, cosfromaxis)
+     *                       DcAtObsXyz, cosfromaxis)
                         if(cosfromaxis .gt. 0.5 ) then
 !                               as gneration for e with 60 deg or less from axis
                            call cobAS(TrackBefMove)
@@ -104,7 +104,6 @@
 !c      integer icon
 
 #if DEBUG == 1
-      deb=.true.
       call checkstat('before fixModel')
 #endif
 
@@ -222,6 +221,9 @@
          call checkstat('before cinteraction')
 #endif
          call cinteraction
+#if DEBUG == 1
+         call checkstat('after cinteraction')
+#endif
       elseif(MoveStat .eq. ToBeObserved ) then
          ptclidx = MovedTrack%p%code  ! make 4 byte integer
          ptclidx = min(ptclidx, 8)   ! this is only for using KEminObs
@@ -288,7 +290,8 @@
       else
          write(msg, *) ' movestat=',MoveStat,' invalid'
          call cerrorMsg(msg, 0)
-      endif   
+      endif
+
       end
       subroutine cresetTimer(aTrack)
       implicit none
@@ -313,8 +316,8 @@
 !         MovedTrack.t = 0.     ! bug bef uv6.09 ;;; but why commentout ??? 
       endif
       end
-!           if you activate the next routine, Epics will have link problem!!!
-!ccc   #if DEBUG > 0
+!           if you activate the next routine, Epics will have link problem  b
+
       subroutine checkstat(str)
       implicit none
 #include  "Ztrack.h"
@@ -454,10 +457,12 @@
             call csampNEPIntL   ! non Electron Photon  Interaction.
          endif
          call cfixProc
+
          if( IntInfArray(ProcessNo)%process == 'coll' ) then
 !               some of the code can not deal with coll.of sigma 
-!               etc.
+!     etc.
             call cseeColPossible( TrackBefMove%p, jcon)
+
             if( jcon == -1) then
 !                  then force to decay
                call cresetIntInf
