@@ -10,9 +10,9 @@
 
 
 
-c            These must be double.  because addition is done 1 by 1
-c            and reach 10^7 or more.(at least  Ng, Ne, at E0
-c            >10^16eV.)
+!            These must be double.  because addition is done 1 by 1
+!            and reach 10^7 or more.(at least  Ng, Ne, at E0
+!            >10^16eV.)
        real*8  SumEloss(maxNoOfASSites),
      *   Ng(maxNoOfASSites), Ne(maxNoOfASSites),  Nmu(maxNoOfASSites),
      *   Nhad(maxNoOfASSites)
