@@ -5,7 +5,7 @@
 #if FNODATDEF > 0
       integer bufc, inbuf,  fnodat
       parameter (fnodat = FNODATDEF)
-      structure /buffer/
+      type buffer
          integer*2 ldep
          integer*2 code
          integer*2 subcode
@@ -20,5 +20,5 @@
          real wy
          real wz
   	 real wgt
-      end structure
+      end type buffer
 #endif
