@@ -1,7 +1,7 @@
-c  FNODATDEF   if undef,  ascii main output; else  binary output:
-c        execSSHtemplate.sh   
-c   or   execSGEtemplate.sh must be modified.
-c
+!  FNODATDEF   if undef,  ascii main output; else  binary output:
+!        execSSHtemplate.sh   
+!   or   execSGEtemplate.sh must be modified.
+!
 #define FNODATDEF 33
       subroutine xBgRun
       implicit none
@@ -22,8 +22,8 @@ c
 #include "Zprivate2.h"
 #include "Zprivate3.h"     
 
-      record /track/ incident
-      record /coord/ AngleAtObs
+      type(track):: incident
+      type(coord):: AngleAtObs
 
       logical  HEobs            ! if T, currently observing 
       common /ZHEobs/ HEobs     !  particle is the one  obsrved at skeelton making time
@@ -37,14 +37,14 @@ c
 
 
       integer id  ! input.  1 ==> aTrack is going out from
-c                                 outer boundery.
-c                           2 ==> reached at an observation level
-c                           3 ==> reached at inner boundery.
-      record /track/ aTrack
+!                                 outer boundery.
+!                           2 ==> reached at an observation level
+!                           3 ==> reached at inner boundery.
+      type(track):: aTrack
 
-      record /track/ inci
-      record /coord/ angle
-      record /coord/ tetafai
+      type(track):: inci
+      type(coord):: angle
+      type(coord):: tetafai
       
       character*128 input
       character*64 dirstr
@@ -90,15 +90,15 @@ c                           3 ==> reached at inner boundery.
       save
 
 
-c     
-c     ***********************
+!     
+!     ***********************
 #include "interface2.f"
-c     *********************
-c     example
-c       histdep:  2 5 6 7 10 /
-c       depth   1000 2000 3000 4000 5000 6000 7000 8000 9000 10000
-c       ansites = 5
-c       w2hl: 0 1 0 0 2 3 4 0 0 5  0 0 ...
+!     *********************
+!     example
+!       histdep:  2 5 6 7 10 /
+!       depth   1000 2000 3000 4000 5000 6000 7000 8000 9000 10000
+!       ansites = 5
+!       w2hl: 0 1 0 0 2 3 4 0 0 5  0 0 ...
       
 
       limit = 20000
@@ -131,10 +131,10 @@ c       w2hl: 0 1 0 0 2 3 4 0 0 5  0 0 ...
          w2il( indivdep(i) ) = i
       enddo
 
-c        now hnsites is the  actual number of sites where statistics
-c        by histogram is needed.
-c        mapping; depth index to array index; where2loc
-c     
+!        now hnsites is the  actual number of sites where statistics
+!        by histogram is needed.
+!        mapping; depth index to array index; where2loc
+!     
 
  
       call kwhistso( binw )  ! specify binary or ascii write of histogaram
@@ -151,13 +151,13 @@ c
       enddo
 
       return      
-c    ******************
+!    ******************
       entry ihist
-c
-c
+!
+!
 
-c     histogram: instanciate
-c         rspec (lateral):  
+!     histogram: instanciate
+!         rspec (lateral):  
       if(tklat) then
          do i = 1, hnsites
             do j = 1, 4         ! g,e,mu,had
@@ -171,9 +171,9 @@ c         rspec (lateral):
       endif
 
 
-c        elosrspec (energy loss lateral)  10m-10km log bin 0.1. e+mu, e,mu
-c          
-c       
+!        elosrspec (energy loss lateral)  10m-10km log bin 0.1. e+mu, e,mu
+!          
+!       
       if(tkelosslat) then
          do i = 1, hnsites
             do j = 1, 3         !   e, mu, e+mu
@@ -203,7 +203,7 @@ c
       endif
          
 
-c
+!
       if(tkrespec) then
          do i = 1, hnsites
             do j= 1, 2
@@ -216,7 +216,7 @@ c
      *         "re", "ptcls", .true.,  1., 
      *         "r", "m.u", "E", "GeV")
             enddo
-c                 mu            
+!                 mu            
             call kwhisti2( respec(3, i),
      *            0.01, 0.2, 20       , b'00011', 
      *            0.031627,  0.1,  38, b'00011' )
@@ -328,7 +328,7 @@ c                 mu
       if(tkretspec)  then
          do i = 1, hnsites
             do j = 1, 2
-c                  g,e
+!                  g,e
                call kwhisti3(retspec1(j, i), 
      *          1.0,     0.2,  10,    b'00011',
      *          500.e-6, 0.25, 15,    b'01001',
@@ -349,7 +349,7 @@ c                  g,e
      *         "ret2", "ptcls", .true., 0.,
      *         "r", "m.u", "E", "GeV", "Time", "ns")
             enddo
-c               mu
+!               mu
             call kwhisti3(retspec1(3, i), 
      *           1.0,   0.2,    10,       b'00011',
      *           100.e-3, 0.25, 10,       b'01011',
@@ -443,11 +443,11 @@ c               mu
       endif
 
       return
-c     *********************************** hook for Beginning of  1 event
-c     *  All system-level initialization for 1 event generation has been
-c     *  eneded at this moment.
-c     *  After this is executed, event generation starts.
-c     *
+!     *********************************** hook for Beginning of  1 event
+!     *  All system-level initialization for 1 event generation has been
+!     *  eneded at this moment.
+!     *  After this is executed, event generation starts.
+!     *
       entry xBgEvent
 
 
@@ -467,16 +467,16 @@ c     *
       else
          NN=1
       endif
-c         next is only available for parallel job.  For normal job,
-c         fisrt col.depth is not yet fixed.
+!         next is only available for parallel job.  For normal job,
+!         fisrt col.depth is not yet fixed.
       firstz= Zfirst.pos.depth*0.1
       write(0,'(a,1pE11.3,a,E11.3,a,E11.3,a)')
      *     ' E0=',E0, ' cosz=',cosz, ' firstz=',
      *    firstz, ' g/cm2' 
-c          here we use enhanced limit
+!          here we use enhanced limit
       call howmuch(limite, E0, NN, cosz)
 
-c      
+!      
       do i = 1, NoOfASSites
          SumEloss(i) = 0.
          Ng(i) = 0.
@@ -611,13 +611,13 @@ c
       obstimes = 0.
 
       return
-c     ***************
+!     ***************
       entry xObs(aTrack, id)
-c
-c     For id =2, you need not output the z value, because it is always
-c     0 (within the computational accuracy).
-c
-c     **************************
+!
+!     For id =2, you need not output the z value, because it is always
+!     0 (within the computational accuracy).
+!
+!     **************************
       obstimes = obstimes + 1.d0
       if(mod(obstimes, 500000.d0) .eq. 0. ) then 
          dosort=.false.
@@ -635,7 +635,7 @@ c     **************************
             write(0,*)' stack tops=', Stack(i).p.fm.p(4)
          enddo
       endif
-c     ***************
+!     ***************
       code = aTrack.p.code
       if(id .eq. 2 .and. code .le. 6) then
          codex=min(code, 4)
@@ -659,37 +659,37 @@ c     ***************
 
          Ek = aTrack.p.fm.p(4) -aTrack.p.mass
 
-c            ---------- compute energy loss rate
+!            ---------- compute energy loss rate
          if(aTrack.p.charge .ne. 0  ) then
             rho = cvh2den(aTrack.pos.height)
-c         get energy loss when aTrack goes 1 g/cm2 along the
-c         primary direction. Gramage the particle can run is
-c         1/cos where cos is the cos of angle relative to the
-c         primary angle . 1g/cm^2 = 10-3kg/10-4 m^2 =10 kg/m^2.
-c         To travel  1 g/cm^2  along shower axis, the ptcl must
-c         run dist kg/m^2
+!         get energy loss when aTrack goes 1 g/cm2 along the
+!         primary direction. Gramage the particle can run is
+!         1/cos where cos is the cos of angle relative to the
+!         primary angle . 1g/cm^2 = 10-3kg/10-4 m^2 =10 kg/m^2.
+!         To travel  1 g/cm^2  along shower axis, the ptcl must
+!         run dist kg/m^2
             if(abs(wz) .gt. 1.d-2) then
                dist =10./wz    ! in kg/m2/(g/cm2)
             else
-c                 for safety
+!                 for safety
                dist =1000.
             endif
             if( HEobs ) then
-c                   the ptcls is the one obsrved at skeleton making time
-c                   we must compute dedt here
+!                   the ptcls is the one obsrved at skeleton making time
+!                   we must compute dedt here
                call cdedxInAir(aTrack.p, rho, dedt) ! dedt; GeV/(kg/m2)
                if(aTrack.p.code .eq. kmuon ) then
-c                 dE/dx due to muon pair, brem, nuc.i
+!                 dE/dx due to muon pair, brem, nuc.i
                   call cmudEdx(MuNI, MuBr, MuPr, aTrack.p.fm.p(4),
      *                 dedxmu)  ! dedxmu in GeV/(g/cm2)
                   dedxmu = dedxmu /10. !  GeV/(kg/m2)
                   dedt = dedt + dedxmu
                endif
             else
-c               we can use already computed one
+!               we can use already computed one
                call cqElossRate(dedt) !  loss rate GeV/(kg/m^2)
             endif
-c                       energy loss rate
+!                       energy loss rate
             Eloss = dedt*dist*enhance   !  GeV/(g/cm2)
 
             SumEloss(ldep)=SumEloss(ldep) + Eloss
@@ -708,7 +708,7 @@ c                       energy loss rate
          else
             ridx =0
          endif
-c           fai is  in    -15 to 345  (for dfai=30.)
+!           fai is  in    -15 to 345  (for dfai=30.)
          fai=atan2(aTrack.pos.xyz.y, aTrack.pos.xyz.x)*
      *        57.29577951308230d0
          fai= mod(fai + 360.d0,   360.d0)
@@ -770,38 +770,38 @@ c           fai is  in    -15 to 345  (for dfai=30.)
          endif
       endif
  100  continue
-c            ------------------
+!            ------------------
       i=w2hl(ldep)
 
       if(id .eq. 2 .and. code .le. 6 .and. i .gt. 0) then
          if( tklat ) then
-c                    lateral
+!                    lateral
             call kwhist(rspec(codex, i), sr, enhance )
          endif
          if( tkelosslat  
      *        .and. aTrack.p.charge .ne. 0 ) then
-cc            de = Eloss*enhance
+!c            de = Eloss*enhance
             de = Eloss
             call kwhist(lossrspec(3,i), sr, de)
             if( code .eq.  kelec ) then
-c                          by electrons
+!                          by electrons
                call kwhist(lossrspec(1,i), sr, de)
             else
-c                      by other charged particles
+!                      by other charged particles
                call kwhist(lossrspec(2,i), sr, de)
             endif
-c                  end of eloss late
+!                  end of eloss late
          endif
 
 
          if(tkarspec) then
-c                arspec
+!                arspec
             call kwhist2( arspec(codex, i), sngl(fai), sr, enhance)
          endif
       endif
       if(id .eq. 2 .and. code .le. 3 .and. i .gt. 0) then
          if( tkrespec ) then
-c                  re spectrum
+!                  re spectrum
             call kwhist2( respec(code, i), sr, Ek, enhance)
          endif
 
@@ -870,20 +870,20 @@ c                  re spectrum
          endif
       endif       
       return
-c     **************
+!     **************
       entry xEnEvent
-c     **************
+!     **************
 #if FNODATDEF > 0
-c      if(fnodat .gt. 0) then
+!      if(fnodat .gt. 0) then
          if(bufc .gt. 0) then
             write(fnodat)  bufc, buf
             bufc=0
          endif
-c      endif
+!      endif
 #endif
 
 
-c      call cqFirstID(firstz)
+!      call cqFirstID(firstz)
       firstz= Zfirst.pos.depth*0.1
 
       if(ObserveAS) then
@@ -905,7 +905,7 @@ c      call cqFirstID(firstz)
             cog = cog + ASObsSites(i).esize*dd*ASDepthList(i)
             sumne= sumne +ASObsSites(i).esize*dd
          enddo
-c          0.1 is for g/cm2
+!          0.1 is for g/cm2
          cog = cog*0.1/sumne
 
          cog2 = 0.
@@ -929,7 +929,7 @@ c          0.1 is for g/cm2
          if(sumne .gt. 0.) then
             cog2 = cog2*0.1/sumne
          else
-c              too deep penetration
+!              too deep penetration
             cog2 = ASDepthList(NoOfASSites)*0.1
          endif
 
@@ -977,8 +977,8 @@ c              too deep penetration
       endif
 
 
-c        here we write limit; at reduce process, non enhanced value
-c        is needed
+!        here we write limit; at reduce process, non enhanced value
+!        is needed
       write(fnonrfai,'(i2,1pE11.3, 0p,i3, f8.4, 1pE11.3,3i4)')
      *   EventNo, E0, NN, cosz, limit, nrbin, nfai, ansites
       do i = 1, ansites
@@ -1004,7 +1004,7 @@ c        is needed
             enddo
          enddo
       enddo
-c           dE/dx lateral
+!           dE/dx lateral
       do i = 1, ansites
          do k = 1, nfai
             l = indivdep(i)
