@@ -1,7 +1,7 @@
       integer Maxp, Maxob, MaxPtclPerCpu, MaxCPU
       parameter (Maxp=1200000, Maxob=60000)
-c      for p10^17 eV Emin=6e3, Maxp~280000 Maxob~23000
-c      parameter (MaxCPU =41960)   ! must be >= NCPU
+!      for p10^17 eV Emin=6e3, Maxp~280000 Maxob~23000
+!      parameter (MaxCPU =41960)   ! must be >= NCPU
       parameter (MaxCPU =1280)   ! must be >= NCPU
       parameter (MaxPtclPerCpu=Maxp/MaxCPU*4/3)
       integer basefn  ! file #; 21 22,....
@@ -13,9 +13,9 @@ c      parameter (MaxCPU =41960)   ! must be >= NCPU
       integer idx(Maxp), idxlocal(MaxCPU)
       integer numba(MaxCPU) 
       integer ctc, Ncpu,  Mcpu, Margin
-      record /track/ ct(Maxp)
-      record /parent/ pp 
-      record /ob/ oo(Maxob) 
+      type(track):: ct(Maxp)
+      type(parent):: pp 
+      type(ob):: oo(Maxob) 
       character*128 msg
       character*120 skelfile(MaxCPU)
       common /arrangec/ ct, pp, oo,  sumergi, sumergw, cpupw,
