@@ -1,31 +1,42 @@
-#include "../cmain.f"
+#include "cmain.f"
 #include "chookHybAS.f"
-#include "../ctemplCeren.f"
-c
-c  *************************************** hook for Beginning of a Run
-c  * At this moment, all (system-level) initialization for this run
-c  * has been ended.  After this routine is executed, the system goes into the
-c  * event creation loop.
-c  *
+#include "ctemplCeren.f"
+#if defined (KEKB) || defined (KEKA)
+#define DOMPI
+#endif
+!
+!  *************************************** hook for Beginning of a Run
+!  * At this moment, all (system-level) initialization for this run
+!  * has been ended.  After this routine is executed, the system goes into the
+!  * event creation loop.
+!  *
       subroutine chookBgRun
       implicit none
 #include "Zmaxdef.h"
 #include "Zmanagerp.h"
 #include "Zprivate.h"
 #include "Ztrack.h"
+! #include "mpif.h"
+! #include "Zmpi.h"
+#if defined (DOMPI)
 #include "mpif.h"
 #include "Zmpi.h"
-
+      real*8 etime1
+      etime1 = MPI_WTIME()
+      write(0,*) 'rank=',mpirank, ' time start=',etime1
+#else
+      integer::mpirank=-1
+#endif
       character*10  append
       character*100 msg
       logical  ex, opn
       integer klena
       if(mpirank .le. 0) then
-c            namelist output
+!            namelist output
          call cwriteParam(ErrorOut, 0)
-c            primary information
+!            primary information
          call cprintPrim(ErrorOut)
-c            observation level information
+!            observation level information
          call cprintObs(ErrorOut)
       endif
 
@@ -59,7 +70,7 @@ c            observation level information
      *    ' SumEHmin=',SumehMin/1000.,'TeV'
       call cerrorMsg(msg, 1)
 
-c     
+!     
       inquire(file=Mskel(1:klena(Mskel)), opened=opn, exist=ex)
       if(opn) then
          call cerrorMsg(Mskel, 1)
@@ -68,7 +79,7 @@ c
      *      append(1:klena(append)) .eq. 'append' ) then
          open(Mdev, file=Mskel, form='unformatted',status='old')
          call cerrorMsg('skeleton node info. will be appended', 1)
-c           skip to the end of file
+!           skip to the end of file
          do while( .true. )
             read(Mdev, end=100)
          enddo
@@ -90,15 +101,15 @@ c           skip to the end of file
      *      status='unknown' )
 
       Accepted = 0   ! counter;  accepted as skeleton 
-c
+!
       end
 
 
-c     *********************************** hook for Beginning of  1 event
-c     *  All system-level initialization for 1 event generation has been
-c     *  eneded at this moment.
-c     *  After this is executed, event generation starts.
-c     *
+!     *********************************** hook for Beginning of  1 event
+!     *  All system-level initialization for 1 event generation has been
+!     *  eneded at this moment.
+!     *  After this is executed, event generation starts.
+!     *
       subroutine chookBgEvent
       implicit none
 #include "Zprivate.h"
@@ -112,8 +123,8 @@ c     *
       
 
 
-      record /track/incident
-      record /coord /angle
+      type(track)::incident
+      type(coord)::angle
 
 
       integer  EventNo
@@ -144,7 +155,7 @@ c     *
 
       rewind  Wdev
 
-c     ===================================================
+!     ===================================================
 
       EventNo = EventNo + 1     
       do i = 1, NoOfSites
@@ -162,41 +173,41 @@ c     ===================================================
       enddo
 
 
-c     ===================================================
+!     ===================================================
       end
   
 
-c     ************************************ hook for observation
-c     *  One particel information is brought here by the system.
-c     *  All information of the particle is in aTrack
-c     *
+!     ************************************ hook for observation
+!     *  One particel information is brought here by the system.
+!     *  All information of the particle is in aTrack
+!     *
       subroutine chookObs(aTrack, id)
-c
-c     Note that every real variable is in double  precision so
-c     that you may output it in sigle precision to save the memory.
-c     In some cases it is essential to put it in sigle (say,
-c     for gnuplot).
-c 
+!
+!     Note that every real variable is in double  precision so
+!     that you may output it in sigle precision to save the memory.
+!     In some cases it is essential to put it in sigle (say,
+!     for gnuplot).
+! 
       implicit none
 #include "Zcode.h"
 #include "Ztrack.h"
 #include "Zprivate.h"
       integer id  ! input.  2 ==> reached at an observation level
-c                           1 ==> aTrack is going out from
-c                                 outer boundery.
-c                           2 ==> reached at an observation level
-c                           3 ==> reached at inner boundery.
-      record /track/ aTrack
-c
-c     For id =2, you need not output the z value, because it is always
-c     0 (within the computational accuracy).
-c
-c     ===================================================
+!                           1 ==> aTrack is going out from
+!                                 outer boundery.
+!                           2 ==> reached at an observation level
+!                           3 ==> reached at inner boundery.
+      type(track)::aTrack
+!
+!     For id =2, you need not output the z value, because it is always
+!     0 (within the computational accuracy).
+!
+!     ===================================================
       common /testcos/sumg, ng(20), nth, EventNo
       real*8 sumg
       integer ng, nth, EventNo
 
-c     ===================================================
+!     ===================================================
       if( id .eq. 2 .and. aTrack.p.code .ne. kneumu .and.
      *   aTrack.p.code .ne. kneue) then
          Np = Np + 1
@@ -217,7 +228,7 @@ c     ===================================================
          o(Np).wy =aTrack.vec.w.r(2)
          o(Np).wz =aTrack.vec.w.r(3)
          o(Np).zenith = aTrack.vec.coszenith
-c     ===================================================
+!     ===================================================
        if( o(Np).code .le. 6 .and. o(Np).code .ne. 3 ) then
          write(*, 959) 
      *  o(Np).where,   
@@ -232,16 +243,16 @@ c     ===================================================
  959    format(3i3, g14.3,2f16.6,4(1x,f12.8))
       endif
 
-c     ===================================================
+!     ===================================================
       endif
-c     ===================================================
+!     ===================================================
 
-c     ===================================================
+!     ===================================================
       end
 
-c    *********************************** hook for end of 1 vent
-c    * At this moment, 1 event generation has been ended.
-c    *
+!    *********************************** hook for end of 1 vent
+!    * At this moment, 1 event generation has been ended.
+!    *
       subroutine chookEnEvent
 
       implicit none
@@ -266,7 +277,7 @@ c    *
 
       sumeg = 0
       sumeh =0
-c         count sum Eg etc
+!         count sum Eg etc
       do i = 1, Np
          if(o(i).where .eq. Where) then
             if(o(i).code .le. kelec) then
@@ -282,39 +293,39 @@ c         count sum Eg etc
          endif
       enddo
 
-c     ===================================================
+!     ===================================================
       memorize =(ng .ge. NgMin .and. sumeg .ge. SumegMin) .or.
      *  ( nh .ge. NhMin .and. sumeh .ge. SumehMin)
 
-c/////
+!/////
       write(0,*) ' memo=', memorize,
      *   ' ng=',ng, ' seg=',sumeg, ' nh=',nh,' seh=',sumeh
-c//////
+!//////
 
 
-c     ===================================================
+!     ===================================================
       if(memorize) then
          Accepted = Accepted + 1
-cc         call cwriteSeed    
-c             !  SeedFile  (seed will be written by cmemorize)
-c          flag for end of 1 event on working disk
+!c         call cwriteSeed    
+!             !  SeedFile  (seed will be written by cmemorize)
+!          flag for end of 1 event on working disk
          write(Wdev)  -1, p
          call cmemorize(Wdev, Mdev)     !  reocord this event
       endif
       end
 
 
-c     ********************************* hook for end of a run
-c     *  all events have been created or time lacks
-c     *
+!     ********************************* hook for end of a run
+!     *  all events have been created or time lacks
+!     *
       subroutine chookEnRun
       implicit none
 #include "Zprivate.h"
       character*100 msg
-c     =========================================
+!     =========================================
 
 
-c     =========================================
+!     =========================================
       call cerrorMsg('++++++++++++', 1)
       write(msg, '(i8, a)') Accepted,
      *       ' events are memorized as skeleton'
@@ -324,14 +335,14 @@ c     =========================================
       close(MdeV)
       call  cprintStatus   ! if don't like,  comment out
       end
-c     ********************************* hook for trace
-c     *  This is called only when trace > 100
-c     *  User should manage the trace information here.
-c     *  If you use this, you may need some output for trace
-c     *  at the beginning of 1 event generatio and at the end of  1 event
-c     *  generation so that you can identfy each event.
-c     *
-c     *
+!     ********************************* hook for trace
+!     *  This is called only when trace > 100
+!     *  User should manage the trace information here.
+!     *  If you use this, you may need some output for trace
+!     *  at the beginning of 1 event generatio and at the end of  1 event
+!     *  generation so that you can identfy each event.
+!     *
+!     *
       subroutine chookTrace
             implicit none
 
@@ -342,72 +353,72 @@ c     *
 #include  "Zobsv.h"
 
        real*4 h1,  h2
-c
-c    Every time a particle is moved in the atmosphere, this routine is called,
-c    if trace > 100
-c         For a one track segment,
-c     TrackBefMove  has  track information at the beginning of the segment.
-c     MoveTrack    has   track information at the end of the segment.
-c   
-c     You can know the  information a track contains in the 
-c     chookObs routine. (Note however, no conversion of coordinate
-c     has been done.  The values are in the Earth xyz system.)
-c     Besides quantities explained there, you can use, for a  given 'track'
-c
-c     atrack.pos.xyz.x, atrack.pos.xyz.y, atrack.pos.xyz.z    (x,y.z)
-c     atrack.pos.radiallen   (distance from the center of the earth)
-c     atrack.pos.depth       (vertical depth)
-c     atrack.pos.height      (vertical heigth from sea level)  
-c
+!
+!    Every time a particle is moved in the atmosphere, this routine is called,
+!    if trace > 100
+!         For a one track segment,
+!     TrackBefMove  has  track information at the beginning of the segment.
+!     MoveTrack    has   track information at the end of the segment.
+!   
+!     You can know the  information a track contains in the 
+!     chookObs routine. (Note however, no conversion of coordinate
+!     has been done.  The values are in the Earth xyz system.)
+!     Besides quantities explained there, you can use, for a  given 'track'
+!
+!     atrack.pos.xyz.x, atrack.pos.xyz.y, atrack.pos.xyz.z    (x,y.z)
+!     atrack.pos.radiallen   (distance from the center of the earth)
+!     atrack.pos.depth       (vertical depth)
+!     atrack.pos.height      (vertical heigth from sea level)  
+!
 
       h1 = TrackBefMove.pos.height- ObsSites(NoOfSites).pos.height
       h2 = MovedTrack.pos.height - ObsSites(NoOfSites).pos.height
 
       end
-c     ********************* this is the hook called when
-c       an electron made an interaction.
-c
+!     ********************* this is the hook called when
+!       an electron made an interaction.
+!
       subroutine chookEInt(never)
       implicit none
 #include  "Zprivate.h"
 #include  "Ztrack.h"
 #include  "Ztrackv.h"
 #include  "Zcode.h"
-c  #include  "Ztrackp.h"
+!  #include  "Ztrackp.h"
       integer never             ! input & output
       integer nlow
-c 
-c    If Job = 'newskel', input  "never" may be < 0,  and MovedTrack
-c    may not be an electron.
-c      never = -1 :  MovedTrack K.E becomes < KEminObs due to
-c                    energy loss during traveling.
-c      never = -2 :  The same as above, but the particle crosses an
-c                    observation depth, so the calling point to this
-c                    routine is different from the never = -1 case.
-c      never = -3 :  K.E >= KEminiObs.  The ptcl is observed at the
-c                    current deepest Obs. level. but at the flesh time
-c                    the deepest level will be more deep so that
-c                    this must be memorized.
-c
-c         For above cases, the product is only MovedTrack and 
-c         no particle is in PWork.
-c  Otherwise,
-c   MovedTrack is the electron that made interaction
-c   Pwork contains produced particles (normally gamma, but mayb  e).
-c   Nproduced has the number of particles in Pwork (normally 1)
-c   IntInfArray(ProcessNo) contains the type of interaction
-c        IntInfArray(ProcessNo).process will have one of
-c       'brems', 'mscat', 'bscat'  'anihi' or 'mbrem'
-c     
+! 
+!    If Job = 'newskel', input  "never" may be < 0,  and MovedTrack
+!    may not be an electron.
+!      never = -1 :  MovedTrack K.E becomes < KEminObs due to
+!                    energy loss during traveling.
+!      never = -2 :  The same as above, but the particle crosses an
+!                    observation depth, so the calling point to this
+!                    routine is different from the never = -1 case.
+!      never = -3 :  K.E >= KEminiObs.  The ptcl is observed at the
+!                    current deepest Obs. level. but at the flesh time
+!                    the deepest level will be more deep so that
+!                    this must be memorized.
+!
+!         For above cases, the product is only MovedTrack and 
+!         no particle is in PWork.
+!  Otherwise,
+!   MovedTrack is the electron that made interaction
+!   Pwork contains produced particles (normally gamma, but mayb  e).
+!   Nproduced has the number of particles in Pwork (normally 1)
+!   IntInfArray(ProcessNo) contains the type of interaction
+!        IntInfArray(ProcessNo).process will have one of
+!       'brems', 'mscat', 'bscat'  'anihi' or 'mbrem'
+!     
       if(never .lt. 0) then
          Nproduced = 1
-c           IBM user must modify next
+!           IBM user must modify next
          Pwork(1) = MovedTrack.p
       endif
 
-c         high energy parent at node might be used
-c        for hybrid AS generation if it is in some
-c        energy region.
+!         high energy parent at node might be used
+!        for hybrid AS generation if it is in some
+!        energy region.
       if( MovedTrack.p.code .eq. kelec ) then
          if( MovedTrack.asflag .eq. 0 ) then
             if( MovedTrack.p.fm.p(4) .lt. Ethresh ) then
@@ -418,7 +429,7 @@ c        energy region.
 
       call cmemoNode(Wdev, never)
       if(MovedTrack.asflag .eq. -1) then
-c          decendent should not be used to  generae A.S
+!          decendent should not be used to  generae A.S
          MovedTrack.asflag  = -2
       endif
 
@@ -426,35 +437,35 @@ c          decendent should not be used to  generae A.S
       never = 0
       end
 
-c     ********************* this is the hook called when
-c       a gamma ray made an interaction.
-c
+!     ********************* this is the hook called when
+!       a gamma ray made an interaction.
+!
       subroutine chookGInt(never)
       implicit none
 #include  "Zprivate.h"
 #include  "Ztrack.h"
 #include  "Ztrackv.h"
-c  #include  "Ztrackp.h"
+!  #include  "Ztrackp.h"
       
       integer never   ! input & output
       
-c         don't make never = 1, if you want to get
-c         information after a gamma ray made interaction
-c         if this is made non zero, this routine will never be called.
-c
-c   MovedTrack is the gamma that made interaction
-c   Pwork contains produced particles.
-c   Nproduced has the number of particles in Pwork
-c   IntInfArray(ProcessNo) contains the type of interaction
-c         IntInfArray(ProcessNo).process will have one of
-c        'pair', 'comp', 'photoe' 'photop' 'mpair'
+!         don't make never = 1, if you want to get
+!         information after a gamma ray made interaction
+!         if this is made non zero, this routine will never be called.
+!
+!   MovedTrack is the gamma that made interaction
+!   Pwork contains produced particles.
+!   Nproduced has the number of particles in Pwork
+!   IntInfArray(ProcessNo) contains the type of interaction
+!         IntInfArray(ProcessNo).process will have one of
+!        'pair', 'comp', 'photoe' 'photop' 'mpair'
       call cmemoNode(Wdev, 1)
       never = 0
       end
 
-c     ********************* this is the hook called when
-c       non e-g particle made an interaction.
-c
+!     ********************* this is the hook called when
+!       non e-g particle made an interaction.
+!
       subroutine chookNEPInt(never)
       implicit none
 #include  "Zprivate.h"
@@ -465,15 +476,15 @@ c
       integer never   ! input & output
 
 
-c         don't make never = 1, if you want to get
-c         information after a non-e-g particle  made interaction
-c         if this is made non zero, this routine will never be called.
-c
-c   MovedTrack is the particle that made interaction
-c   Pwork contains produced particles.
-c   Nproduced has the number of particles in Pwork
-c   IntInfArray(ProcessNo) contains the type of interaction
-c
+!         don't make never = 1, if you want to get
+!         information after a non-e-g particle  made interaction
+!         if this is made non zero, this routine will never be called.
+!
+!   MovedTrack is the particle that made interaction
+!   Pwork contains produced particles.
+!   Nproduced has the number of particles in Pwork
+!   IntInfArray(ProcessNo) contains the type of interaction
+!
 
       call cmemoNode(Wdev, 1)
       never = 0
@@ -486,52 +497,52 @@ c
 #include  "Ztrackv.h"
 #include  "Ztrackp.h"
 #include  "Zprivate.h"
-c
+!
       integer dev  ! input. fortran logical dev. number for data write
       integer flag ! input. If this is -3, high energy particles must
                    !       also be memorized.
-c
-c
-c       memorize nodal information at interaction.
-c     
-c        \
-c         \  projectile    = MovedTrack
-c         /|\  produced particles.: Pwork(i), i=1~Nproduced
-c        / | \
-c
-c   From projectile, the track information is extracted
-c   From produced particles, only those of K.E< KEminObs is
-c   extracted and information needed for further tracking is 
-c   obtaned and memorized. The position information is common
-c   to all the children.
-c
-c   Track   information;   pos =
-c                                xyz = r(1~3), sys
-c                                radiallen, depth, height, colheight
-c                            t
-c                          vec  =
-c                                 w = r(1~3), sys
-c                                 coszenith
-c                          wgt
-c                         where
-c                        asflag 
-c
-c      Among these, we don't memorize 
-c         sys which is always 'xyz'
-c       radiallen: can be computed from height
-c         vec; children knows  their direction
-c         wgt: normally not needed, it should be 1 for skeleton making
-c              So thinsamping must not be used when making skeleton.
-c      asflag: should be always F, (assume for skeleton making, hybrid
-c              air shower is not requested)       
-c
-c   write  track info. of projectile
-c
+!
+!
+!       memorize nodal information at interaction.
+!     
+!        \
+!         \  projectile    = MovedTrack
+!         /|\  produced particles.: Pwork(i), i=1~Nproduced
+!        / | \
+!
+!   From projectile, the track information is extracted
+!   From produced particles, only those of K.E< KEminObs is
+!   extracted and information needed for further tracking is 
+!   obtaned and memorized. The position information is common
+!   to all the children.
+!
+!   Track   information;   pos =
+!                                xyz = r(1~3), sys
+!                                radiallen, depth, height, colheight
+!                            t
+!                          vec  =
+!                                 w = r(1~3), sys
+!                                 coszenith
+!                          wgt
+!                         where
+!                        asflag 
+!
+!      Among these, we don't memorize 
+!         sys which is always 'xyz'
+!       radiallen: can be computed from height
+!         vec; children knows  their direction
+!         wgt: normally not needed, it should be 1 for skeleton making
+!              So thinsamping must not be used when making skeleton.
+!      asflag: should be always F, (assume for skeleton making, hybrid
+!              air shower is not requested)       
+!
+!   write  track info. of projectile
+!
       integer i, nlow
       real*8 ke
 
-c
-c
+!
+!
       nlow = 0 
       do i = 1, Nproduced
          ke = Pwork(i).fm.p(4) - Pwork(i).mass 
@@ -539,24 +550,24 @@ c
      *       ke .ge.  Cuteg ) .or. 
      *       ( Pwork(i).code .gt. kelec .and.          
      *       ke .ge.  Cutneg ) ) then
-c              count low energy ptcls
+!              count low energy ptcls
             if(flag .ne. -3) then
                if( ke .lt.  KEminObs(1)) then
                   nlow = nlow + 1
                endif
             else
-c               all ptcl must be memorized
+!               all ptcl must be memorized
                nlow = nlow + 1
             endif
          endif
       enddo
-c         next is harmful for B-approx air shower
-c         because, parent is not memorized and cannot
-c         generate AS at flesh time at proper positon
-c         asflag == -1 must apear in flesh
-c      if(nlow .eq. 0 )  return !  *************
-c       if there is no return here, the size of skeleton data
-c       becomes 3.2 times larger
+!         next is harmful for B-approx air shower
+!         because, parent is not memorized and cannot
+!         generate AS at flesh time at proper positon
+!         asflag == -1 must apear in flesh
+!      if(nlow .eq. 0 )  return !  *************
+!       if there is no return here, the size of skeleton data
+!       becomes 3.2 times larger
       if(nlow .eq. 0  .and. MovedTrack.asflag .ne. -1) return
 
 
@@ -578,17 +589,17 @@ c       becomes 3.2 times larger
       p.asflag = MovedTrack.asflag
 
 
-cc
-cc     *           p.posx, p.posy, p.posz, p.depth, p.height, 
-cc     *           p.colHeight, p.atime, p.where
-cc
-c       write particle info
-c           p(1~4)
-c           mass
-c           code
-c           subcode
-c           charge
-c 
+!c
+!c     *           p.posx, p.posy, p.posz, p.depth, p.height, 
+!c     *           p.colHeight, p.atime, p.where
+!c
+!       write particle info
+!           p(1~4)
+!           mass
+!           code
+!           subcode
+!           charge
+! 
 
 
       write(dev) nlow, p
@@ -617,14 +628,18 @@ c
       enddo
       end
 
-c        
+!        
       subroutine cmemorize(from, to)
       implicit none
 #include "Zmaxdef.h"
 #include  "Ztrack.h"
 #include  "Ztrackv.h"
+#ifdef  DOMPI       
 #include "mpif.h"
 #include  "Zmpi.h"
+#else
+       integer::mpirank = -1
+#endif      
       integer from      !  working disk file 
       integer to        !  permanent disk file where skeleton is sotered
 
@@ -632,13 +647,13 @@ c
 
 
       integer num, cumnum, irevent(2)
-c      record /track/ incident
-c      record /coord/ angle
+!      record /track/ incident
+!      record /coord/ angle
 
 
       rewind from
-c          need not memorize, can be generated at flesh
-c      call cqIncident(incident, angle)      
+!          need not memorize, can be generated at flesh
+!      call cqIncident(incident, angle)      
 
       call cqEventNo(num, cumnum)
 
@@ -663,9 +678,9 @@ c      call cqIncident(incident, angle)
       implicit none
 #include "Zprivate.h"
       integer to
-c
-c        write high energy sekeleton data into 'to'      
-c
+!
+!        write high energy sekeleton data into 'to'      
+!
       integer i
 
       write(to) Np
