@@ -1,16 +1,16 @@
 #include "BlockData/cblkGene.h"
-c  #include "jamdat.f"
+!  #include "jamdat.f"
 #include "jamdummy.h"
 #include "phitsdummy.h"
-c #include "Zphitsblk.h"
-c       main program of cosmos
+! #include "Zphitsblk.h"
+!       main program of cosmos
       program Cosmos
 #include "ZcosmosExt.h"
 #include "jamextrn.inc"
-c///////////
-c         call mydummy
-c         call myPhitsDummy
-c/////////////
+!///////////
+!         call mydummy
+!         call myPhitsDummy
+!/////////////
          call cmanager   ! call Manager for Cosmos Simulation
       end
 
