@@ -1,11 +1,12 @@
-c #ifndef  Zmagfield_
-c #define  Zmagfield_
+! #ifndef  Zmagfield_
+! #define  Zmagfield_
 #include "Zunionmap.h"
-c
-       structure /magfield/
-c          Note that position vector where the magnetic field is given
-c          is not included here.
-c          unit of field strength is  in T (1 gauss = 10**-4 T)
+!
+       type magfield
+         sequence
+!          Note that position vector where the magnetic field is given
+!          is not included here.
+!          unit of field strength is  in T (1 gauss = 10**-4 T)
 #ifdef  UNIONMAP
          union
               map
@@ -15,7 +16,11 @@ c          unit of field strength is  in T (1 gauss = 10**-4 T)
      *                   z        !
 
 #ifdef UNIONMAP
-              endmap              ! 'hva'.  this is for geomag.
+              endmap          !   
+              map
+                 real(8):: F(3)
+              endmap           ! same as x,y,z
+              
               map
                   real*8 n,      ! north com.
      *                   e,      ! east comp.
@@ -29,7 +34,7 @@ c          unit of field strength is  in T (1 gauss = 10**-4 T)
               endmap 
           endunion     
 #endif
-c  
+!  
           character*4 sys  ! which system. 'xyz',  'ned',  'hva'
-        end structure
-c  #endif  /* Zmagfield.h */
+        end type magfield
+!  #endif  /* Zmagfield.h */
