@@ -1,5 +1,5 @@
 
-c             common for std atmosphere.    
+!             common for std atmosphere.    
       real*8 AlmostVacH  ! almost vacuum height
       real*8 AlmostVacT  ! thickness there
       parameter (AlmostVacH = 101.d3, AlmostVacT = 1.d-3)
@@ -8,4 +8,4 @@ c             common for std atmosphere.
 
       common /comstdatm/  ha, hb, hl, hm, hn, hc, t0,
      *         hmi, hlhmi
-c     -----------------------------------
+!     -----------------------------------
